==> shardingsphere-sql-federation-api-5.2.1-sources.jar: org/apache/shardingsphere/sqlfederation/spi/SQLFederationExecutorContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.sqlfederation.spi;

import lombok.Getter;
import lombok.RequiredArgsConstructor;
import org.apache.shardingsphere.infra.binder.QueryContext;
import org.apache.shardingsphere.infra.executor.sql.context.ExecutionUnit;
import org.apache.shardingsphere.infra.metadata.database.ShardingSphereDatabase;

import java.util.Collection;
import java.util.LinkedList;
import java.util.Map;

/**
 * SQL federation executor context.
 */
@RequiredArgsConstructor
@Getter
public final class SQLFederationExecutorContext {
    
    private final Collection<ExecutionUnit> executionUnits = new LinkedList<>();
    
    private final boolean preview;
    
    private final QueryContext queryContext;
    
    private final Map<String, ShardingSphereDatabase> databases;
}

==> shardingsphere-sql-federation-api-5.3.2-sources.jar: org/apache/shardingsphere/sqlfederation/spi/SQLFederationExecutorContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.sqlfederation.spi;

import lombok.Getter;
import lombok.RequiredArgsConstructor;
import org.apache.shardingsphere.infra.binder.QueryContext;
import org.apache.shardingsphere.infra.executor.sql.context.ExecutionUnit;
import org.apache.shardingsphere.infra.metadata.ShardingSphereMetaData;

import java.util.Collection;
import java.util.LinkedList;

/**
 * SQL federation executor context.
 */
@RequiredArgsConstructor
@Getter
public final class SQLFederationExecutorContext {
    
    private final Collection<ExecutionUnit> executionUnits = new LinkedList<>();
    
    private final boolean preview;
    
    private final QueryContext queryContext;
    
    private final ShardingSphereMetaData metaData;
}
